@@ -1,5 +1,5 @@
 package Kwim::Grammar;
-$Kwim::Grammar::VERSION = '0.0.5';
+$Kwim::Grammar::VERSION = '0.0.6';
 use base 'Pegex::Grammar';
 
 use constant file => '../kwim-pgx/kwim.pgx';
@@ -18,6 +18,9 @@ sub make_tree {
     'block_blank' => {
       '.ref' => 'line_blank'
     },
+    'block_code' => {
+      '.rgx' => qr/\G\\\\\\/
+    },
     'block_comment' => {
       '.rgx' => qr/\G\#\#\#\r?\n((?:.*?\r?\n)*?)\#\#\#\r?\n(?:\ *\r?\n)?/
     },
@@ -84,6 +87,9 @@ sub make_tree {
     'block_pref' => {
       '.rgx' => qr/\G((?:(?:\ *\r?\n)*\ \ .*\r?\n)+)(?:\ *\r?\n)?/
     },
+    'block_rule' => {
+      '.rgx' => qr/\G\-{4}\r?\n(?:\ *\r?\n)?/
+    },
     'block_title' => {
       '.rgx' => qr/\G((?:(?![\ \*=\#\n]\ ).*\S.*(?:\r?\n|\z)))={3,}\r?\n(?:(?:\ *\r?\n)((?:(?![\ \*=\#\n]\ ).*\S.*(?:\r?\n|\z)))(?=(?:\ *\r?\n)|\z))?(?:\ *\r?\n)?/
     },
@@ -98,9 +104,15 @@ sub make_tree {
         {
           '.ref' => 'line_comment'
         },
+        {
+          '.ref' => 'block_rule'
+        },
         {
           '.ref' => 'block_head'
         },
+        {
+          '.ref' => 'block_code'
+        },
         {
           '.ref' => 'block_pref'
         },
@@ -143,12 +155,6 @@ sub make_tree {
     'marker_escape' => {
       '.rgx' => qr/\G\\(.)/
     },
-    'marker_func_end' => {
-      '.rgx' => qr/\G\>/
-    },
-    'marker_func_start' => {
-      '.rgx' => qr/\G</
-    },
     'marker_next' => {
       '.rgx' => qr/\G([\s\S])/
     },
@@ -222,26 +228,7 @@ sub make_tree {
       ]
     },
     'phrase_func' => {
-      '.all' => [
-        {
-          '.ref' => 'marker_func_start'
-        },
-        {
-          '+min' => 1,
-          '-flat' => 1,
-          '.any' => [
-            {
-              '.rgx' => qr/\G([^\>]+)/
-            },
-            {
-              '.ref' => 'phrase_func'
-            }
-          ]
-        },
-        {
-          '.ref' => 'marker_func_end'
-        }
-      ]
+      '.rgx' => qr/\G<([^\>]+)\>/
     },
     'phrase_hyper' => {
       '.any' => [
