@@ -1,6 +1,6 @@
 use strict;
 package Kwim::HTML;
-$Kwim::HTML::VERSION = '0.0.5';
+$Kwim::HTML::VERSION = '0.0.6';
 use base 'Kwim::Markup';
 # use XXX -with => 'YAML::XS';
 
@@ -32,6 +32,10 @@ sub render_para {
     "<p>$spacer$out$spacer</p>\n";
 }
 
+sub render_rule {
+    "<hr/>\n";
+}
+
 sub render_blank {
     "<br/>\n";
 }
